==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/libraries/razorqt/translations/librazorqt_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../addplugindialog/addplugindialog.ui" line="14"/>
        <source>Add plugins</source>
        <translation>添加插件</translation>
    </message>
    <message>
        <location filename="../addplugindialog/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>搜索：</translation>
    </message>
    <message>
        <location filename="../addplugindialog/addplugindialog.ui" line="52"/>
        <source>Add plugin</source>
        <translation>添加插件</translation>
    </message>
    <message>
        <location filename="../addplugindialog/addplugindialog.ui" line="59"/>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
</context>
<context>
    <name>Battery</name>
    <message>
        <location filename="../librazor-upower/battery.cpp" line="68"/>
        <source>%1 : Properties changed</source>
        <translation>%1 ：属性已更改</translation>
    </message>
    <message>
        <location filename="../librazor-upower/battery.cpp" line="74"/>
        <source>%1 : Low</source>
        <translation>%1 ：低</translation>
    </message>
    <message>
        <location filename="../librazor-upower/battery.cpp" line="84"/>
        <source>%1 : Full</source>
        <translation>%1 ：满</translation>
    </message>
</context>
<context>
    <name>PowerManager</name>
    <message>
        <location filename="../powermanager.cpp" line="94"/>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="101"/>
        <source>Suspend</source>
        <translation>挂起</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="108"/>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="115"/>
        <source>Shutdown</source>
        <translation>关机</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="120"/>
        <source>Logout</source>
        <translation>注销</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="132"/>
        <source>Razor Session Suspend</source>
        <translation>挂起Razor会话</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="133"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>你真的要挂起你的计算机吗？&lt;p&gt;挂起的计算机将进入低功耗状态。 电源丢失后系统状态不会被保存。</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="144"/>
        <source>Razor Session Hibernate</source>
        <translation>休眠Razor会话</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="145"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>你真的要将你的计算机休眠吗？&lt;p&gt;休眠的计算机将进入低功耗状态。 电源丢失后系统状态不会被保存。</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="156"/>
        <source>Razor Session Reboot</source>
        <translation>重启Razor会话</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="157"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>你真的想要重启你的计算机吗？ 所有未保存的任务都将丢失……</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="168"/>
        <source>Razor Session Shutdown</source>
        <translation>关闭电源</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="169"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>你真的想要关闭你的计算机吗？ 所有未保存的任务都将丢失……</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="180"/>
        <source>Razor Session Logout</source>
        <translation>注销Razor会话</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="181"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>你真的想要注销你的计算机吗？ 所有未保存的任务都将丢失……</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="193"/>
        <location filename="../powermanager.cpp" line="198"/>
        <source>Razor Power Manager Error</source>
        <translation>Razor电源管理器错误</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="193"/>
        <source>Hibernate failed.</source>
        <translation>休眠失败。</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="198"/>
        <source>Suspend failed.</source>
        <translation>挂起失败。</translation>
    </message>
</context>
<context>
    <name>RazorShortcutButton</name>
    <message>
        <location filename="../razorshortcutbutton.cpp" line="48"/>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
    <message>
        <location filename="../razorshortcutbutton.cpp" line="160"/>
        <source>None</source>
        <translation>无</translation>
    </message>
</context>
<context>
    <name>ScreenSaver</name>
    <message>
        <location filename="../screensaver.cpp" line="48"/>
        <source>Lock Screen</source>
        <translation>锁屏</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="67"/>
        <location filename="../screensaver.cpp" line="75"/>
        <location filename="../screensaver.cpp" line="83"/>
        <location filename="../screensaver.cpp" line="95"/>
        <location filename="../screensaver.cpp" line="103"/>
        <location filename="../screensaver.cpp" line="111"/>
        <location filename="../screensaver.cpp" line="120"/>
        <source>Screen Saver Activation Error</source>
        <translation>屏幕保护程序激活出错</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="68"/>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started due its crash.</source>
        <translation>启动屏幕保护时一个错误发生：xdg-screensaver由于崩溃而不能启动。</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="76"/>
        <source>An error occurred starting screensaver. xdg-screensaver is not installed correctly.</source>
        <translation>启动屏幕保护时一个错误发生：xdg-screensaver没有正确地安装。</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="84"/>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started.</source>
        <translation>启动屏幕保护时一个错误发生：xdg-screensaver不能启动。</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="96"/>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>启动屏幕保护时一个错误发生：xdg-screensaver参数有语法错误。</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="104"/>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>启动屏幕保护时一个错误发生：请确保你安装并运行了xscreensaver。</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="112"/>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>启动屏幕保护时一个错误发生：“激活”失败。请确保你安装并运行了xscreensaver。</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="121"/>
        <source>An error occurred starting screensaver. Unkown error - undocumented return value from xdg-screensaver=%1.</source>
        <translation>启动屏幕保护时一个错误发生：未知错误，从xdg-screensaver=%1 返回的值未归档。</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <location filename="../razoraboutdlg.ui" line="14"/>
        <source> About Razor</source>
        <translation>关于Razor</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/libraries/razorqt/translations/librazorqt_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.0">
<context>
    <name>AddPluginDialog</name>
    <message>
        <source>Add plugins</source>
        <translation>添加插件</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>搜索：</translation>
    </message>
    <message>
        <source>Add plugin</source>
        <translation>添加插件</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
</context>
<context>
    <name>PowerManager</name>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>挂起</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>注销</translation>
    </message>
    <message>
        <source>Razor Session Suspend</source>
        <translation>挂起Razor会话</translation>
    </message>
    <message>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>你真的要挂起你的计算机吗？&lt;p&gt;挂起的计算机将进入低功耗状态。 电源丢失后系统状态不会被保存。</translation>
    </message>
    <message>
        <source>Razor Session Hibernate</source>
        <translation>休眠Razor会话</translation>
    </message>
    <message>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>你真的要将你的计算机休眠吗？&lt;p&gt;休眠的计算机将进入低功耗状态。 电源丢失后系统状态不会被保存。</translation>
    </message>
    <message>
        <source>Razor Session Reboot</source>
        <translation>重启Razor会话</translation>
    </message>
    <message>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>你真的想要重启你的计算机吗？ 所有未保存的任务都将丢失……</translation>
    </message>
    <message>
        <source>Razor Session Shutdown</source>
        <translation>关闭电源</translation>
    </message>
    <message>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>你真的想要关闭你的计算机吗？ 所有未保存的任务都将丢失……</translation>
    </message>
    <message>
        <source>Razor Session Logout</source>
        <translation>注销Razor会话</translation>
    </message>
    <message>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>你真的想要注销你的计算机吗？ 所有未保存的任务都将丢失……</translation>
    </message>
    <message>
        <source>Razor Power Manager Error</source>
        <translation>Razor电源管理器错误</translation>
    </message>
    <message>
        <source>Hibernate failed.</source>
        <translation>休眠失败。</translation>
    </message>
    <message>
        <source>Suspend failed.</source>
        <translation>挂起失败。</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Power Manager Error</source>
        <translation>电源管理错误</translation>
    </message>
    <message>
        <source>QDBusInterface is invalid</source>
        <translation>QDBusInterface 不正确</translation>
    </message>
    <message>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>电源管理错误 (D-BUS 调用)</translation>
    </message>
</context>
<context>
    <name>RazorAboutDLGPrivate</name>
    <message>
        <source>Version: %1</source>
        <translation>版本：%1</translation>
    </message>
    <message>
        <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
        <translation>基于 Qt 技术的高级、易用、快速的桌面环境</translation>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <translation>版权所有：%1-%2 %3</translation>
    </message>
    <message>
        <source>Homepage: %1</source>
        <translation>主页：%1</translation>
    </message>
    <message>
        <source>License: %1</source>
        <translation>协议：%1</translation>
    </message>
    <message>
        <source>Razor-qt is developed by the &lt;a %1&gt;Razor-qt Team and contributors&lt;/a&gt; on Github.</source>
        <translation>Razor-qt 由 Github 上的&lt;a %1&gt;Razor-qt 团队和贡献者&lt;/a&gt;开发。</translation>
    </message>
    <message>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <translation>如果您对我们的工作感兴趣，&lt;a %1&gt;欢迎加入&lt;/a&gt;。</translation>
    </message>
    <message>
        <source>Special thanks to:</source>
        <translation>特别致谢：</translation>
    </message>
    <message>
        <source>Razor-qt is translated into many languages thanks to the work of the translation teams all over the world.</source>
        <translation>Razor-qt 已被翻译成多种语言，特别感谢来自世界各地的翻译团队的努力。</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <source>No</source>
        <translation>否</translation>
    </message>
    <message>
        <source>&lt;b&gt;Razor Desktop Toolbox - Technical Info&lt;/b&gt;</source>
        <translation>&lt;b&gt;Razor 桌面工具箱 - 技术信息&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>Qt</source>
        <translation>Qt</translation>
    </message>
    <message>
        <source>Debug Build</source>
        <translation>调试版本</translation>
    </message>
    <message>
        <source>System Configuration</source>
        <translation>系统配置</translation>
    </message>
    <message>
        <source>Share Directory</source>
        <translation>共享目录</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>翻译</translation>
    </message>
    <message>
        <source>&lt;b&gt;User Directories&lt;/b&gt;</source>
        <translation>&lt;b&gt;用户目录&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Xdg Data Home</source>
        <translation>Xdg 数据位置</translation>
    </message>
    <message>
        <source>Xdg Config Home</source>
        <translation>Xdg 配置文件</translation>
    </message>
    <message>
        <source>Xdg Data Dirs</source>
        <translation>Xdg 数据目录</translation>
    </message>
    <message>
        <source>Xdg Cache Home</source>
        <translation>Xdg 缓存目录</translation>
    </message>
    <message>
        <source>Xdg Runtime Home</source>
        <translation>Xdg 运行时目录</translation>
    </message>
    <message>
        <source>Xdg Autostart Dirs</source>
        <translation>Xdg 开机启动目录</translation>
    </message>
    <message>
        <source>Xdg Autostart Home</source>
        <translation>Xdg 开机启动文件</translation>
    </message>
</context>
<context>
    <name>RazorConfigDialog</name>
    <message>
        <source>Dialog</source>
        <translation>对话框</translation>
    </message>
</context>
<context>
    <name>RazorNotificationPrivate</name>
    <message>
        <source>Notifications Fallback</source>
        <translation>后备消息通知</translation>
    </message>
</context>
<context>
    <name>RazorShortcutButton</name>
    <message>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
</context>
<context>
    <name>ScreenSaver</name>
    <message>
        <source>Lock Screen</source>
        <translation>锁屏</translation>
    </message>
    <message>
        <source>Screen Saver Activation Error</source>
        <translation>屏幕保护程序激活出错</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started due its crash.</source>
        <translation>启动屏幕保护时一个错误发生：xdg-screensaver由于崩溃而不能启动。</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver is not installed correctly.</source>
        <translation>启动屏幕保护时一个错误发生：xdg-screensaver没有正确地安装。</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started.</source>
        <translation>启动屏幕保护时一个错误发生：xdg-screensaver不能启动。</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>启动屏幕保护时一个错误发生：xdg-screensaver参数有语法错误。</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>启动屏幕保护时一个错误发生：请确保你安装并运行了xscreensaver。</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>启动屏幕保护时一个错误发生：“激活”失败。请确保你安装并运行了xscreensaver。</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver=%1.</source>
        <translation>启动屏幕保护时出错。未知错误 - xdg-screensaver=%1 返回非正式返回值。</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source> About Razor</source>
        <translation>关于Razor</translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>作者</translation>
    </message>
    <message>
        <source>Thanks</source>
        <translation>致谢</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>翻译</translation>
    </message>
    <message>
        <source>Technical Info</source>
        <translation>技术信息</translation>
    </message>
</context>
</TS>
